==> haskell-crypto-pubkey-types-0.4.3-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-HdvzQRRx5I98v7TWHlW4sd
key: crypto-pubkey-types-0.4.3-HdvzQRRx5I98v7TWHlW4sd
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Types.PubKey.RSA Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.ECC
    Crypto.Types.PubKey.ECDSA
abi: 1deb25db670cf075e312425d4268ebaa
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-HdvzQRRx5I98v7TWHlW4sd
depends:
    asn1-encoding-0.9.5-4hijzDN35y4QB3uXzlCct
    asn1-types-0.3.2-5wnfVxEnJ3kDfiPJu0Wloe base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-9GfhzDdwQCrIYxAOnYPyS9
key: crypto-pubkey-types-0.4.3-9GfhzDdwQCrIYxAOnYPyS9
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Types.PubKey.RSA Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.ECC
    Crypto.Types.PubKey.ECDSA
abi: a2f03f695c09cd8e14a0e5f9ca5fe0bb
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-9GfhzDdwQCrIYxAOnYPyS9
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
